@@ -522,8 +522,7 @@ void MarblePart::readSettings()
     // Time
     if( MarbleSettings::systemTime() == true  )
     {
-        m_controlView->marbleModel()->setClockDateTime( QDateTime::currentDateTime().toUTC() );
-        m_controlView->marbleModel()->setClockSpeed( 1 );
+        /* nothing to do */
     }
     else if( MarbleSettings::lastSessionTime() == true )
     {
@@ -1264,6 +1263,7 @@ void MarblePart::showMapWizard()
     mapWizard->exec();
     MarbleSettings::setWmsServers( mapWizard->wmsServers() );
     MarbleSettings::setStaticUrlServers( mapWizard->staticUrlServers() );
+    mapWizard->deleteLater();
 }
 
 void MarblePart::editSettings()
